'''
IVI-Example
This example illustrates how to call IVI-Driver from Python.
It is based on the Arbitrary-Sequence Example of the WX218x IVI-Driver.

In order to install comtypes (python library) use the following command from command-line:
>> pip install comtypes

'''
import comtypes
import comtypes.client as cc
import comtypes.gen as cg

import sys
import warnings
import numpy as np
import math

 
comtypes.CoInitialize()
 
#cc.GetModule('IviDriverTypeLib.dll')
#cc.GetModule('IviSessionFactory.dll')
#cc.GetModule('IviFgenTypeLib.dll')


cc.GetModule('wx218x.dll')

# The GUID of the registered wx218x COM Object:
wx218x_guid = '{185D62A6-86BC-4B0D-8FEF-F35F0A0FC943}'
 
strStandardInitOptions = 'Cache=true, InterchangeCheck=false, QueryInstrStatus=false, RangeCheck=true, RecordCoercions=false, Simulate=false'

strResourceDesc = 'TCPIP::192.168.0.197::5025::SOCKET'
 
WX218xLib = cg.WX218xLib #cg.WX218xLib._EB5FFD1F_180B_400E_9FED_46AF13B65982_0_2_0


wx218x = None


try:
    wx218x = cc.CreateObject(wx218x_guid)
    wx218x.Initialize(strResourceDesc, True, True, strStandardInitOptions) 
except:
    wrn_msg = "{0}".format(sys.exc_info())
    warnings.warn(wrn_msg)
    wx218x = None


if wx218x is not None:
    try:
        wx218x.Utility.Reset()
                
        print
        print "InstrumentModel: {0:s}".format(wx218x.Identity.InstrumentModel)
        print "InstrumentFirmwareRevision: {0:s}".format(wx218x.Identity.InstrumentFirmwareRevision)
        print "InstrumentManufacturer: {0:s}".format(wx218x.Identity.InstrumentManufacturer)
        print
        print "--------------------------"
        print "Arbitrary Sequence Example"
        print "--------------------------"
        
        wx218x.Arbitrary.Sequence.QuickSequence = 0
        
        wave_sizes = [384, 992, 81920, 10240, 384, 4096, 40960, 204800]
        num_waves = len(wave_sizes)
        
        
        
        
        for chanNb, chanName in zip((1,2), ('Channel1', 'Channel2')): 
            
            print "- Select Channel {0:d}".format(chanNb)           
            wx218x.ActiveChannel = chanName            
            wx218x.Output.OutputMode = WX218xLib.WX218xOutputModeArbitrary
            wx218x.Arbitrary.SampleRate = 75E6
            wx218x.Output.Enabled[chanName] = True
            wx218x.Output.Sync.Enabled[chanName] = True
            
            # Create and write the segments data:
            print "- Create {0} segments (of various lengths) each with single sine-cycle ..".format(num_waves)
            seg_handle = [ 0 ] * num_waves           
            for i, wav_sz in zip(range(num_waves), wave_sizes):
                wav_dat = np.sin(np.linspace(0, 2 * math.pi, num=wav_sz, endpoint=False))
                seg_nb = i + 1
                wx218x.Arbitrary.Waveform.SetActiveSegment(chanName, seg_nb)
                seg_handle[i] = wx218x.Arbitrary.Waveform.Create(wav_dat)
                gain, offset = 0.5, 0
                wx218x.Arbitrary.Waveform.Configure(chanName, seg_handle[i], gain, offset)
            
            # Create 3 Simple Sequences:
            print "- Create 3 Simple Sequences (based on the defined segments) .."            
            seq_handle = [ 0, 0, 0 ]
            
            # Sequence 1:
            segment_nb = [ seg_handle[4], seg_handle[0], seg_handle[7] ]
            loop_count = [ 2, 4, 6 ]
            jump_flag  = np.array([0, 1, 1], dtype=np.uint8)
            
            wx218x.Arbitrary.Sequence.SetActiveSequence(chanName, 1)
            seq_handle[0] = wx218x.Arbitrary.Sequence.CreateSequenceAdv(segment_nb, loop_count, jump_flag)
            
            # Sequence 2:
            segment_nb = [ seg_handle[1], seg_handle[2], seg_handle[7], seg_handle[6], seg_handle[4] ]
            loop_count = [ 3, 4, 1, 3, 5 ]
            jump_flag  = np.array([ 0, 1, 1, 0, 0 ], dtype=np.uint8)
            wx218x.Arbitrary.Sequence.SetActiveSequence(chanName, 2)
            seq_handle[1] = wx218x.Arbitrary.Sequence.CreateSequenceAdv(segment_nb, loop_count, jump_flag)
            
            # Sequence 3:
            segment_nb = [ seg_handle[2], seg_handle[3], seg_handle[1], seg_handle[0], seg_handle[4], seg_handle[6], seg_handle[5] ]
            loop_count = [ 8, 4, 6, 3, 2, 2, 5 ]
            jump_flag  = np.array([ 0, 1, 1, 1, 0, 1, 1 ], dtype=np.uint8)
            wx218x.Arbitrary.Sequence.SetActiveSequence(chanName, 3)
            seq_handle[2] = wx218x.Arbitrary.Sequence.CreateSequenceAdv(segment_nb, loop_count, jump_flag)
            
            
            # Create Advanced Sequence:
            print "- Create Advanced Sequence (based on the defined simple-sequences) ..".format(num_waves)
            sequence_nb = [ seq_handle[2], seq_handle[0], seq_handle[1] ]
            loop_count = [ 2, 4, 3 ]
            jump_flag  = np.array([0, 1, 1], dtype=np.uint8)
            wx218x.Arbitrary.Sequence.AdvanceSequence.CreateAdvSequence(sequence_nb, loop_count, jump_flag)
            
            # Select Advanced-Sequence Mode:
            wx218x.Output.OutputMode = WX218xLib.WX218xOutputModeASequence 
            
            print           
            
    except:
        wrn_msg = "{0}".format(sys.exc_info())
        warnings.warn(wrn_msg)
    
    errNb, errMsg = wx218x.Utility.ErrorQuery()
    
    wx218x.Close()
    wx218x = None

 
comtypes.CoUninitialize()




print "End of example: status = {0} ({1})".format(errNb, errMsg)





    

  

